@@ -19,9 +19,9 @@
 
 """Speaks information about the current object of interest."""
 
-__id__        = "$Id: where_am_I.py 2475 2007-06-15 14:25:41Z shaeger $"
-__version__   = "$Revision: 2475 $"
-__date__      = "$Date: 2007-06-15 10:25:41 -0400 (Fri, 15 Jun 2007) $"
+__id__        = "$Id: where_am_I.py 2514 2007-07-03 13:15:24Z shaeger $"
+__version__   = "$Revision: 2514 $"
+__date__      = "$Date: 2007-07-03 09:15:24 -0400 (Tue, 03 Jul 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -640,7 +640,7 @@ class WhereAmI:
             return
       
         # Try to get the URI of the active document and parse it
-        doc_uri = self.__getDocumentFrameURI(obj)
+        doc_uri = self._script.getDocumentFrameURI()
         if doc_uri:
             doc_uri_info = urlparse.urlparse(doc_uri)
         else:
@@ -719,20 +719,6 @@ class WhereAmI:
             # Translators: This is the size of a file in megabytes
             #
             return _('%.2f megabytes') % (float(size) * .000001) 
-        
-    def __getDocumentFrameURI(self, obj):
-        '''
-        Returns the URI of the document frame that is active
-        '''
-        try:
-            documentFrame = self._script.getDocumentFrame()
-        except AttributeError:
-            return None
-        attrs = documentFrame.document.getAttributes()
-        for attr in attrs:
-            if attr.startswith('DocURL'):
-                return attr[7:]
-        return None
 
     def _speakGenericObject(self, obj, doubleClick):
         """Speak a generic object; one not specifically handled by
